@@ -45,9 +45,10 @@ class DraftFilesComponent(ServiceComponent):
         """
         draft = record
         enabled = data.get("files", {}).get("enabled", True)
+        default_preview = data.get("files", {}).get("default_preview")
 
         try:
-            self.files_component.assign_files_enabled(enabled, record=draft)
+            self.files_component.assign_files_enabled(draft, enabled)
         except ValidationError as e:
             errors.append(
                 {
@@ -68,6 +69,19 @@ class DraftFilesComponent(ServiceComponent):
                 }
             )
 
+        try:
+            self.files_component.assign_files_default_preview(
+                draft,
+                default_preview,
+            )
+        except ValidationError as e:
+            errors.append(
+                {
+                    "field": "files.default_preview",
+                    "messages": e.messages
+                }
+            )
+
     def edit(self, identity, draft=None, record=None):
         """Edit callback."""
         if draft.bucket is None:
